rot_symmetry_z — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# rot_symmetry_z

ElectronicBandStructure.rot_symmetry_z(order, kpoints, bands, projected, sx, sy, sz)

  Applies the given rotational crystal symmetry to the current system. ie: to unfold the irreductible BZ to the full BZ.

  Only rotations along z-axis are performed, you can use self.GeneralRotation first.

  The user is responsible of provide a useful input. The method doesn’t check the physics.